# frozen_string_literal: true

class AddHgAsDefaultVcs < ActiveRecord::Migration[6.1]
  include Gitlab::Database::MigrationHelpers

  disable_ddl_transaction!

  def up
    change_column_default :application_settings, :vcs_types, %w"hg git"
    change_column_default :application_settings, :default_vcs_type, "hg"

    execute(
      <<SQL
        -- add 'hg' to the list
        UPDATE application_settings
        SET vcs_types = vcs_types || '["hg"]'::jsonb
        WHERE NOT vcs_types ? 'hg';

        -- remove 'hg_git' from the list
        UPDATE application_settings
        SET vcs_types = vcs_types - 'hg_git';

        -- set 'hg' as default vcs type at application level
        UPDATE application_settings
        SET default_vcs_type = 'hg'
        WHERE default_vcs_type = 'hg_git';

        -- set 'hg' as default vcs type for namespaces
        UPDATE namespaces
        SET default_vcs_type = 'hg'
        WHERE default_vcs_type = 'hg_git';
SQL
    )
  end

  def down
    change_column_default :application_settings, :vcs_types, %w"hg_git git"
    change_column_default :application_settings, :default_vcs_type, "hg_git"
  end
end
