# frozen_string_literal: true

module Gitlab
  module ImportExport
    module Project
      class VcsTypeRestorer < TreeRestorer
        # even though we don't need the `user` attribute,
        # subclassing `initialize` is not in order, as it behaves badly with the
        # monkey patching of `new` done by RSpec (call_original on TreeRestorer)

        def restore
          unless relation_reader
            raise Gitlab::ImportExport::Error, 'invalid import format'
          end

          project_attributes = relation_reader.consume_attributes(importable_path)
          # Using "git" default value to accept Git projects exported from a
          # regular GitLab instance
          @project.vcs_type = project_attributes.fetch("vcs_type", "git")
          true
        rescue StandardError => e
          @shared.error(e)
          false
        end
      end
    end
  end
end
