# frozen_string_literal: true

module Gitlab
  module ImportExport
    class RepoRestorer
      include Gitlab::ImportExport::CommandLineUtil

      attr_reader :importable

      def initialize(importable:, shared:, path_to_bundle:)
        @path_to_bundle = path_to_bundle
        @shared = shared
        @importable = importable
      end

      def restore
        check_path = path_to_bundle
        check_path = check_path.sub(/\.bundle$/, '.hg.bundle') if repository.mercurial?

        return true unless File.exist?(check_path)

        ensure_repository_does_not_exist!

        repository.create_from_bundle(path_to_bundle)
        update_importable_repository_info

        true
      rescue StandardError => e
        shared.error(e)
        false
      end

      def repository
        @repository ||= importable.repository
      end

      private

      attr_accessor :path_to_bundle, :shared

      def update_importable_repository_info
        # No-op. Overridden in EE
      end

      def ensure_repository_does_not_exist!
        if repository.exists?
          shared.logger.info(
            message: %Q{Deleting existing "#{repository.disk_path}" to re-import it.}
          )

          Repositories::DestroyService.new(repository).execute
        end
      end
    end
  end
end

Gitlab::ImportExport::RepoRestorer.prepend_mod_with('Gitlab::ImportExport::RepoRestorer')
