# frozen_string_literal: true

module Gitlab
  module Vcs
    REPOSITORY_CLASSES = {
      "hg_git" => Gitlab::Mercurial::HgGitRepository,
      "hg" => Gitlab::Mercurial::HgitalyRepository,
      "git" => Gitlab::Git::Repository
    }.freeze

    WIKI_CLASSES = {
      "hg_git" => Gitlab::Mercurial::Wiki,
      "hg" => Gitlab::Mercurial::Wiki,
      "git" => Gitlab::Git::Wiki
    }.freeze

    SUPPORTED_TYPES = REPOSITORY_CLASSES.keys.freeze

    DEFAULT_TYPE = "hg"

    class << self
      def repository_class(vcs_type)
        REPOSITORY_CLASSES.fetch(vcs_type.to_s)
      end

      def wiki_class(vcs_type)
        WIKI_CLASSES.fetch(vcs_type.to_s)
      end
    end
  end
end
